@@ -12,6 +12,9 @@ from tendenci.core.perms.object_perms import ObjectPermission
 from tendenci.apps.user_groups.models import Group, GroupMembership
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.base.fields import EmailVerificationField
+from tendenci.apps.redirects.models import Redirect
+from django.http import HttpResponseRedirect
+from django.shortcuts import get_object_or_404
 
 #STATUS_DRAFT = 1
 #STATUS_PUBLISHED = 2
@@ -132,6 +135,14 @@ class Form(TendenciBaseModel):
     admin_link_export.allow_tags = True
     admin_link_export.short_description = ""
 
+    def has_files(self):
+        for entry in self.entries.all():
+            for field in entry.fields.all():
+                if field.field.field_type == 'FileField':
+                    return True
+        return False
+
+
 class FieldManager(models.Manager):
     """
     Only show visible fields when displaying actual form..
@@ -286,6 +297,8 @@ class FormEntry(models.Model):
             field = entry.field
             if field.field_type.lower() == 'emailfield':
                 email = entry.value
+            if field.field_type.lower() == 'emailverificationfield':
+                email = entry.value
             if field.label.lower() in ['name']:
                 name = entry.value
             if field.label.lower() in ['first name']:
@@ -338,7 +351,7 @@ class FormEntry(models.Model):
         return self.get_value_of("EmailPhoneNumber")
 
     def get_email_address(self):
-        return self.get_type_of("emailfield")
+        return self.get_type_of("emailverificationfield")
 
      # Called by payments_pop_by_invoice_user in Payment model.
     def get_payment_description(self, inv):
