@@ -17,6 +17,7 @@ from tendenci.core.event_logs.models import EventLog
 from tendenci.core.meta.models import Meta as MetaTags
 from tendenci.core.meta.forms import MetaForm
 from tendenci.core.versions.models import Version
+from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import (update_perms_and_save,
                                        get_notice_recipients,
                                        has_perm,
@@ -32,12 +33,12 @@ from tendenci.apps.pages.models import Page, HeaderImage
 from tendenci.apps.pages.forms import PageForm
 
 
-def index(request, slug=None, id=None, hash=None, 
+@is_enabled('pages')
+def index(request, slug=None, id=None, hash=None,
           template_name="pages/view.html"):
     """
     Return page object, either as an archive, active, or version.
     """
-
     if not slug and not id and not hash:
         return HttpResponseRedirect(reverse('page.search'))
 
@@ -87,6 +88,7 @@ def index(request, slug=None, id=None, hash=None,
         context_instance=RequestContext(request))
 
 
+@is_enabled('pages')
 def search(request, template_name="pages/search.html"):
     """
     Search pages.
@@ -112,6 +114,7 @@ def search(request, template_name="pages/search.html"):
         context_instance=RequestContext(request))
 
 
+@is_enabled('pages')
 def print_view(request, slug, template_name="pages/print-view.html"):
     page = get_object_or_404(Page, slug=slug, status_detail='active')
 
@@ -123,6 +126,8 @@ def print_view(request, slug, template_name="pages/print-view.html"):
     return render_to_response(template_name, {'page': page},
         context_instance=RequestContext(request))
 
+
+@is_enabled('pages')
 @login_required
 def edit(request, id, form_class=PageForm,
          meta_form_class=MetaForm,
@@ -236,12 +241,12 @@ def edit(request, id, form_class=PageForm,
         context_instance=RequestContext(request))
 
 
+@is_enabled('pages')
 @login_required
 def edit_meta(request, id, form_class=MetaForm, template_name="pages/edit-meta.html"):
     """
     Return page that allows you to edit meta-html information.
     """
-
     # check permission
     page = get_object_or_404(Page, pk=id)
     if not has_perm(request.user, 'pages.change_page', page):
@@ -271,6 +276,7 @@ def edit_meta(request, id, form_class=MetaForm, template_name="pages/edit-meta.h
     return render_to_response(template_name, {'page': page, 'form': form},
         context_instance=RequestContext(request))
 
+
 @login_required
 def preview(request, id=None, form_class=PageForm, meta_form_class=MetaForm,
         category_form_class=CategoryForm, template="pages/preview.html"):
@@ -318,14 +324,15 @@ def preview(request, id=None, form_class=PageForm, meta_form_class=MetaForm,
                                                 'categoryform': categoryform,
                                                 'edit_button': edit_button},
                context_instance=RequestContext(request))
-        
+
     return HttpResponseRedirect(reverse('page.search'))
 
+
+@is_enabled('pages')
 @login_required
 def add(request, form_class=PageForm, meta_form_class=MetaForm,
         category_form_class=CategoryForm,
         template_name="pages/add.html"):
-
     if not has_perm(request.user, 'pages.add_page'):
         raise Http403
 
@@ -426,6 +433,7 @@ def add(request, form_class=PageForm, meta_form_class=MetaForm,
             context_instance=RequestContext(request))
 
 
+@is_enabled('pages')
 @login_required
 def delete(request, id, template_name="pages/delete.html"):
     page = get_object_or_404(Page, pk=id)
@@ -458,6 +466,7 @@ def delete(request, id, template_name="pages/delete.html"):
         context_instance=RequestContext(request))
 
 
+@is_enabled('pages')
 def display_header_image(request, id):
     page = get_object_or_404(Page, pk=id)
 
@@ -469,10 +478,10 @@ def display_header_image(request, id):
     return file_display(request, page.header_image.file.name)
 
 
+@is_enabled('pages')
 @login_required
 def export(request, template_name="pages/export.html"):
     """Export Pages"""
-
     if not request.user.is_superuser:
         raise Http403
 
