@@ -6,13 +6,14 @@ from tendenci.core.perms.admin import TendenciBaseModelAdmin
 
 
 class GroupAdmin(TendenciBaseModelAdmin):
-    list_display = ['name', 'label', 'show_as_option', 'allow_self_add', 'allow_self_remove', 'admin_status']
-    search_fields = ['name', 'label']
-    list_filter = ['status']
+    list_display = ['id', 'name', 'label', 'entity', 'show_as_option', 'allow_self_add', 'allow_self_remove', 'admin_status']
+    search_fields = ['name', 'label', 'entity']
+    list_filter = ['status', 'entity', 'show_as_option', 'allow_self_add']
+    list_editable = ['name', 'label', 'entity']
     fieldsets = (
         (None, {'fields': ('name', 'label', 'entity', 'email_recipient', 'permissions')}),
         ('Flags', {'fields': (
-            'show_as_option', 'allow_self_add', 'allow_self_remove')}),
+            'show_as_option', 'allow_self_add', 'allow_self_remove', 'sync_newsletters')}),
         ('Administrative', {'fields': (
             'allow_anonymous_view', 'user_perms', 'member_perms', 'group_perms', 'status', 'status_detail')}),
     )
