@@ -145,7 +145,7 @@ class GroupMembership(models.Model):
         verbose_name_plural = "Group Memberships"
 
     @classmethod
-    def add_to_group(cls, *kwargs):
+    def add_to_group(cls, **kwargs):
         """
         Easily add someone to a group, we're setting basic defaults
         e.g. GroupMembership.add_to_group(member=member, group=group)
@@ -159,9 +159,9 @@ class GroupMembership(models.Model):
         return cls.objects.create(
             group=group,
             member=member,
-            creator=editor,
+            creator_id=editor.pk,
             creator_username=editor.username,
-            owner=editor,
+            owner_id=editor.pk,
             owner_username=editor.username,
             status=status,
             status_detail=status_detail
